@@ -8,9 +8,9 @@ logger = logging.getLogger(__name__)
 
 
 class ONNXModelParserStage(Stage):
-    def __init__(self, list_of_callables, *, onnx_model, mapping_path, **kwargs):
+    def __init__(self, list_of_callables, *, workload, mapping, **kwargs):
         super().__init__(list_of_callables, **kwargs)
-        self.onnx_model_parser = ONNXModelParser(onnx_model, mapping_path)
+        self.onnx_model_parser = ONNXModelParser(workload, mapping)
     
     def run(self) -> Generator:
         self.onnx_model_parser.run()
